You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@qpid.apache.org by ru...@apache.org on 2007/08/17 12:19:55 UTC

svn commit: r567003 - in /incubator/qpid/branches/M2/java/perftests: ./ src/main/java/org/apache/qpid/ping/ src/main/java/org/apache/qpid/requestreply/

Author: rupertlssmith
Date: Fri Aug 17 03:19:54 2007
New Revision: 567003

URL: http://svn.apache.org/viewvc?view=rev&rev=567003
Log:
Tests enhanced for fanout style tests with many consumers per destination.

Modified:
    incubator/qpid/branches/M2/java/perftests/pom.xml
    incubator/qpid/branches/M2/java/perftests/src/main/java/org/apache/qpid/ping/PingDurableClient.java
    incubator/qpid/branches/M2/java/perftests/src/main/java/org/apache/qpid/ping/PingTestPerf.java
    incubator/qpid/branches/M2/java/perftests/src/main/java/org/apache/qpid/requestreply/PingPongProducer.java
    incubator/qpid/branches/M2/java/perftests/src/main/java/org/apache/qpid/requestreply/PingPongTestPerf.java

Modified: incubator/qpid/branches/M2/java/perftests/pom.xml
URL: http://svn.apache.org/viewvc/incubator/qpid/branches/M2/java/perftests/pom.xml?view=diff&rev=567003&r1=567002&r2=567003
==============================================================================
--- incubator/qpid/branches/M2/java/perftests/pom.xml (original)
+++ incubator/qpid/branches/M2/java/perftests/pom.xml Fri Aug 17 03:19:54 2007
@@ -325,48 +325,69 @@
                              No rate limiting.
                              Message sizes from 128 bytes to 1 Meg.
                         -->
-                        <!--
-                        <TQB-Qpid-01>-n TQB-Qpid-01           -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=1   batchSize=1000   messageSize=256     destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false</TQB-Qpid-01>
-                        <TQB-Qpid-02>-n TQB-Qpid-02           -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=1   batchSize=1000   messageSize=256     destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false</TQB-Qpid-02>
-                        <PQB-Qpid-01>-n PQB-Qpid-01           -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=true  commitBatchSize=1   batchSize=1000   messageSize=256     destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false</PQB-Qpid-01>
-                        <PQB-Qpid-02>-n PQB-Qpid-02           -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=false commitBatchSize=1   batchSize=1000   messageSize=256     destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false</PQB-Qpid-02>
-                        -->
-
-                        <TQB-Qpid-01-512b>-n TQB-Qpid-01-512b -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=10  batchSize=1000   messageSize=512     destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false</TQB-Qpid-01-512b>
-                        <TQB-Qpid-01-1K>-n TQB-Qpid-01-1K     -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=10  batchSize=1000   messageSize=1024    destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false</TQB-Qpid-01-1K>
-                        <TQB-Qpid-01-5K>-n TQB-Qpid-01-5K     -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=10  batchSize=1000   messageSize=5120    destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false</TQB-Qpid-01-5K>
-                        <TQB-Qpid-01-10K>-n TQB-Qpid-01-10K   -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=10  batchSize=1000   messageSize=10240   destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false</TQB-Qpid-01-10K>
-                        <TQB-Qpid-01-50K>-n TQB-Qpid-01-50K   -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=10  batchSize=1000   messageSize=51200   destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false</TQB-Qpid-01-50K>
-                        <TQB-Qpid-01-100K>-n TQB-Qpid-01-100K -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=10  batchSize=1000   messageSize=102400  destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false</TQB-Qpid-01-100K>
-                        <TQB-Qpid-01-500K>-n TQB-Qpid-01-500K -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=10  batchSize=1000   messageSize=512000  destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false</TQB-Qpid-01-500K>
-                        <TQB-Qpid-01-1M>-n TQB-Qpid-01-1M     -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=10  batchSize=1000   messageSize=1048576 destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false</TQB-Qpid-01-1M>
-
-                        <TQB-Qpid-02-512b>-n TQB-Qpid-02-512b -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=10  batchSize=1000   messageSize=512     destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false</TQB-Qpid-02-512b>
-                        <TQB-Qpid-02-1K>-n TQB-Qpid-02-1K     -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=10  batchSize=1000   messageSize=1024    destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false</TQB-Qpid-02-1K>
-                        <TQB-Qpid-02-5K>-n TQB-Qpid-02-5K     -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=10  batchSize=1000   messageSize=5120    destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false</TQB-Qpid-02-5K>
-                        <TQB-Qpid-02-10K>-n TQB-Qpid-02-10K   -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=10  batchSize=1000   messageSize=10240   destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false</TQB-Qpid-02-10K>
-                        <TQB-Qpid-02-50K>-n TQB-Qpid-02-50K   -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=10  batchSize=1000   messageSize=51200   destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false</TQB-Qpid-02-50K>
-                        <TQB-Qpid-02-100K>-n TQB-Qpid-02-100K -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=10  batchSize=1000   messageSize=102400  destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false</TQB-Qpid-02-100K>
-                        <TQB-Qpid-02-500K>-n TQB-Qpid-02-500K -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=10  batchSize=1000   messageSize=512000  destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false</TQB-Qpid-02-500K>
-                        <TQB-Qpid-02-1M>-n TQB-Qpid-02-1M     -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=10  batchSize=1000   messageSize=1048576 destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false</TQB-Qpid-02-1M>
-
-                        <PQB-Qpid-01-512b>-n PQB-Qpid-01-512b -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=10  batchSize=1000   messageSize=512     destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false</PQB-Qpid-01-512b>
-                        <PQB-Qpid-01-1K>-n PQB-Qpid-01-1K     -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=10  batchSize=1000   messageSize=1024    destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false</PQB-Qpid-01-1K>
-                        <PQB-Qpid-01-5K>-n PQB-Qpid-01-5K     -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=10  batchSize=1000   messageSize=5120    destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false</PQB-Qpid-01-5K>
-                        <PQB-Qpid-01-10K>-n PQB-Qpid-01-10K   -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=10  batchSize=1000   messageSize=10240   destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false</PQB-Qpid-01-10K>
-                        <PQB-Qpid-01-50K>-n PQB-Qpid-01-50K   -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=10  batchSize=1000   messageSize=51200   destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false</PQB-Qpid-01-50K>
-                        <PQB-Qpid-01-100K>-n PQB-Qpid-01-100K -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=10  batchSize=1000   messageSize=102400  destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false</PQB-Qpid-01-100K>
-                        <PQB-Qpid-01-500K>-n PQB-Qpid-01-500K -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=10  batchSize=1000   messageSize=512000  destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false</PQB-Qpid-01-500K>
-                        <PQB-Qpid-01-1M>-n PQB-Qpid-01-1M     -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=10  batchSize=1000   messageSize=1048576 destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false</PQB-Qpid-01-1M>
-
-                        <PQB-Qpid-02-512b>-n PQB-Qpid-02-512b -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=10  batchSize=1000   messageSize=512     destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false</PQB-Qpid-02-512b>
-                        <PQB-Qpid-02-1K>-n PQB-Qpid-02-1K     -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=10  batchSize=1000   messageSize=1024    destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false</PQB-Qpid-02-1K>
-                        <PQB-Qpid-02-5K>-n PQB-Qpid-02-5K     -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=10  batchSize=1000   messageSize=5120    destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false</PQB-Qpid-02-5K>
-                        <PQB-Qpid-02-10K>-n PQB-Qpid-02-10K   -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=10  batchSize=1000   messageSize=10240   destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false</PQB-Qpid-02-10K>
-                        <PQB-Qpid-02-50K>-n PQB-Qpid-02-50K   -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=10  batchSize=1000   messageSize=51200   destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false</PQB-Qpid-02-50K>
-                        <PQB-Qpid-02-100K>-n PQB-Qpid-02-100K -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=10  batchSize=1000   messageSize=102400  destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false</PQB-Qpid-02-100K>
-                        <PQB-Qpid-02-500K>-n PQB-Qpid-02-500K -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=10  batchSize=1000   messageSize=512000  destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false</PQB-Qpid-02-500K>
-                        <PQB-Qpid-02-1M>-n PQB-Qpid-02-1M     -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=10  batchSize=1000   messageSize=1048576 destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false</PQB-Qpid-02-1M>
+                        <TQB-Qpid-01-1C> -n TQB-Qpid-01       -d1M  -s[1000]   -c[1]                  -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=1   batchSize=1000   messageSize=256     destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false numConsumers=1 </TQB-Qpid-01-1C>
+                        <TQB-Qpid-01-2C> -n TQB-Qpid-01       -d1M  -s[1000]   -c[1]                  -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=1   batchSize=1000   messageSize=256     destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false numConsumers=2 </TQB-Qpid-01-2C>
+                        <TQB-Qpid-01-4C> -n TQB-Qpid-01       -d1M  -s[1000]   -c[1]                  -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=1   batchSize=1000   messageSize=256     destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false numConsumers=4 </TQB-Qpid-01-4C>
+                        <TQB-Qpid-01-8C> -n TQB-Qpid-01       -d1M  -s[1000]   -c[1]                  -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=1   batchSize=1000   messageSize=256     destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false numConsumers=8 </TQB-Qpid-01-8C>
+                        <TQB-Qpid-01-16C>-n TQB-Qpid-01       -d1M  -s[1000]   -c[1]                  -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=1   batchSize=1000   messageSize=256     destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false numConsumers=16</TQB-Qpid-01-16C>
+                        <TQB-Qpid-01-32C>-n TQB-Qpid-01       -d1M  -s[1000]   -c[1]                  -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=1   batchSize=1000   messageSize=256     destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false numConsumers=32</TQB-Qpid-01-32C>
+
+                        <TQB-Qpid-02-1C> -n TQB-Qpid-02       -d1M  -s[1000]   -c[1]                  -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=1   batchSize=1000   messageSize=256     destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false numConsumers=1 </TQB-Qpid-02-1C>
+                        <TQB-Qpid-02-2C> -n TQB-Qpid-02       -d1M  -s[1000]   -c[1]                  -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=1   batchSize=1000   messageSize=256     destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false numConsumers=2 </TQB-Qpid-02-2C>
+                        <TQB-Qpid-02-4C> -n TQB-Qpid-02       -d1M  -s[1000]   -c[1]                  -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=1   batchSize=1000   messageSize=256     destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false numConsumers=4 </TQB-Qpid-02-4C>
+                        <TQB-Qpid-02-8C> -n TQB-Qpid-02       -d1M  -s[1000]   -c[1]                  -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=1   batchSize=1000   messageSize=256     destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false numConsumers=8 </TQB-Qpid-02-8C>
+                        <TQB-Qpid-02-16C>-n TQB-Qpid-02       -d1M  -s[1000]   -c[1]                  -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=1   batchSize=1000   messageSize=256     destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false numConsumers=16</TQB-Qpid-02-16C>
+                        <TQB-Qpid-02-32C>-n TQB-Qpid-02       -d1M  -s[1000]   -c[1]                  -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=1   batchSize=1000   messageSize=256     destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false numConsumers=32</TQB-Qpid-02-32C>
+
+                        <PQB-Qpid-01-1C> -n PQB-Qpid-01       -d1M  -s[1000]   -c[1]                  -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=true  commitBatchSize=1   batchSize=1000   messageSize=256     destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false numConsumers=1 </PQB-Qpid-01-1C>
+                        <PQB-Qpid-01-2C> -n PQB-Qpid-01       -d1M  -s[1000]   -c[1]                  -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=true  commitBatchSize=1   batchSize=1000   messageSize=256     destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false numConsumers=2 </PQB-Qpid-01-2C>
+                        <PQB-Qpid-01-4C> -n PQB-Qpid-01       -d1M  -s[1000]   -c[1]                  -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=true  commitBatchSize=1   batchSize=1000   messageSize=256     destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false numConsumers=4 </PQB-Qpid-01-4C>
+                        <PQB-Qpid-01-8C> -n PQB-Qpid-01       -d1M  -s[1000]   -c[1]                  -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=true  commitBatchSize=1   batchSize=1000   messageSize=256     destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false numConsumers=8 </PQB-Qpid-01-8C>
+                        <PQB-Qpid-01-16C>-n PQB-Qpid-01       -d1M  -s[1000]   -c[1]                  -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=true  commitBatchSize=1   batchSize=1000   messageSize=256     destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false numConsumers=16</PQB-Qpid-01-16C>
+                        <PQB-Qpid-01-32C>-n PQB-Qpid-01       -d1M  -s[1000]   -c[1]                  -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=true  commitBatchSize=1   batchSize=1000   messageSize=256     destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false numConsumers=32</PQB-Qpid-01-32C>
+
+                        <PQB-Qpid-02-1C> -n PQB-Qpid-02       -d1M  -s[1000]   -c[1]                  -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=false commitBatchSize=1   batchSize=1000   messageSize=256     destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false numConsumers=1 </PQB-Qpid-02-1C>
+                        <PQB-Qpid-02-2C> -n PQB-Qpid-02       -d1M  -s[1000]   -c[1]                  -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=false commitBatchSize=1   batchSize=1000   messageSize=256     destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false numConsumers=2 </PQB-Qpid-02-2C>
+                        <PQB-Qpid-02-4C> -n PQB-Qpid-02       -d1M  -s[1000]   -c[1]                  -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=false commitBatchSize=1   batchSize=1000   messageSize=256     destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false numConsumers=4 </PQB-Qpid-02-4C>
+                        <PQB-Qpid-02-8C> -n PQB-Qpid-02       -d1M  -s[1000]   -c[1]                  -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=false commitBatchSize=1   batchSize=1000   messageSize=256     destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false numConsumers=8 </PQB-Qpid-02-8C>
+                        <PQB-Qpid-02-16C>-n PQB-Qpid-02       -d1M  -s[1000]   -c[1]                  -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=false commitBatchSize=1   batchSize=1000   messageSize=256     destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false numConsumers=16</PQB-Qpid-02-16C>
+                        <PQB-Qpid-02-32C>-n PQB-Qpid-02       -d1M  -s[1000]   -c[1]                  -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=false commitBatchSize=1   batchSize=1000   messageSize=256     destinationCount=1  rate=0     maxPending=80000000 uniqueDests=false numConsumers=32</PQB-Qpid-02-32C>
+
+                        <TQB-Qpid-01-512b>-n TQB-Qpid-01-512b -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=1   batchSize=1000   messageSize=512     destinationCount=1  rate=0     maxPending=80000000 uniqueDests=true </TQB-Qpid-01-512b>
+                        <TQB-Qpid-01-1K>-n TQB-Qpid-01-1K     -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=1   batchSize=1000   messageSize=1024    destinationCount=1  rate=0     maxPending=80000000 uniqueDests=true </TQB-Qpid-01-1K>
+                        <TQB-Qpid-01-5K>-n TQB-Qpid-01-5K     -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=1   batchSize=1000   messageSize=5120    destinationCount=1  rate=0     maxPending=80000000 uniqueDests=true </TQB-Qpid-01-5K>
+                        <TQB-Qpid-01-10K>-n TQB-Qpid-01-10K   -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=1   batchSize=1000   messageSize=10240   destinationCount=1  rate=0     maxPending=80000000 uniqueDests=true </TQB-Qpid-01-10K>
+                        <TQB-Qpid-01-50K>-n TQB-Qpid-01-50K   -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=1   batchSize=1000   messageSize=51200   destinationCount=1  rate=0     maxPending=80000000 uniqueDests=true </TQB-Qpid-01-50K>
+                        <TQB-Qpid-01-100K>-n TQB-Qpid-01-100K -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=1   batchSize=1000   messageSize=102400  destinationCount=1  rate=0     maxPending=80000000 uniqueDests=true </TQB-Qpid-01-100K>
+                        <TQB-Qpid-01-500K>-n TQB-Qpid-01-500K -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=1   batchSize=1000   messageSize=512000  destinationCount=1  rate=0     maxPending=80000000 uniqueDests=true </TQB-Qpid-01-500K>
+                        <TQB-Qpid-01-1M>-n TQB-Qpid-01-1M     -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=true  commitBatchSize=1   batchSize=1000   messageSize=1048576 destinationCount=1  rate=0     maxPending=80000000 uniqueDests=true </TQB-Qpid-01-1M>
+
+                        <TQB-Qpid-02-512b>-n TQB-Qpid-02-512b -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=1   batchSize=1000   messageSize=512     destinationCount=1  rate=0     maxPending=80000000 uniqueDests=true </TQB-Qpid-02-512b>
+                        <TQB-Qpid-02-1K>-n TQB-Qpid-02-1K     -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=1   batchSize=1000   messageSize=1024    destinationCount=1  rate=0     maxPending=80000000 uniqueDests=true </TQB-Qpid-02-1K>
+                        <TQB-Qpid-02-5K>-n TQB-Qpid-02-5K     -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=1   batchSize=1000   messageSize=5120    destinationCount=1  rate=0     maxPending=80000000 uniqueDests=true </TQB-Qpid-02-5K>
+                        <TQB-Qpid-02-10K>-n TQB-Qpid-02-10K   -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=1   batchSize=1000   messageSize=10240   destinationCount=1  rate=0     maxPending=80000000 uniqueDests=true </TQB-Qpid-02-10K>
+                        <TQB-Qpid-02-50K>-n TQB-Qpid-02-50K   -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=1   batchSize=1000   messageSize=51200   destinationCount=1  rate=0     maxPending=80000000 uniqueDests=true </TQB-Qpid-02-50K>
+                        <TQB-Qpid-02-100K>-n TQB-Qpid-02-100K -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=1   batchSize=1000   messageSize=102400  destinationCount=1  rate=0     maxPending=80000000 uniqueDests=true </TQB-Qpid-02-100K>
+                        <TQB-Qpid-02-500K>-n TQB-Qpid-02-500K -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=1   batchSize=1000   messageSize=512000  destinationCount=1  rate=0     maxPending=80000000 uniqueDests=true </TQB-Qpid-02-500K>
+                        <TQB-Qpid-02-1M>-n TQB-Qpid-02-1M     -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=false pubsub=false transacted=false commitBatchSize=1   batchSize=1000   messageSize=1048576 destinationCount=1  rate=0     maxPending=80000000 uniqueDests=true </TQB-Qpid-02-1M>
+
+                        <PQB-Qpid-01-512b>-n PQB-Qpid-01-512b -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=true  commitBatchSize=1   batchSize=1000   messageSize=512     destinationCount=1  rate=0     maxPending=80000000 uniqueDests=true </PQB-Qpid-01-512b>
+                        <PQB-Qpid-01-1K>-n PQB-Qpid-01-1K     -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=true  commitBatchSize=1   batchSize=1000   messageSize=1024    destinationCount=1  rate=0     maxPending=80000000 uniqueDests=true </PQB-Qpid-01-1K>
+                        <PQB-Qpid-01-5K>-n PQB-Qpid-01-5K     -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=true  commitBatchSize=1   batchSize=1000   messageSize=5120    destinationCount=1  rate=0     maxPending=80000000 uniqueDests=true </PQB-Qpid-01-5K>
+                        <PQB-Qpid-01-10K>-n PQB-Qpid-01-10K   -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=true  commitBatchSize=1   batchSize=1000   messageSize=10240   destinationCount=1  rate=0     maxPending=80000000 uniqueDests=true </PQB-Qpid-01-10K>
+                        <PQB-Qpid-01-50K>-n PQB-Qpid-01-50K   -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=true  commitBatchSize=1   batchSize=1000   messageSize=51200   destinationCount=1  rate=0     maxPending=80000000 uniqueDests=true </PQB-Qpid-01-50K>
+                        <PQB-Qpid-01-100K>-n PQB-Qpid-01-100K -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=true  commitBatchSize=1   batchSize=1000   messageSize=102400  destinationCount=1  rate=0     maxPending=80000000 uniqueDests=true </PQB-Qpid-01-100K>
+                        <PQB-Qpid-01-500K>-n PQB-Qpid-01-500K -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=true  commitBatchSize=1   batchSize=1000   messageSize=512000  destinationCount=1  rate=0     maxPending=80000000 uniqueDests=true </PQB-Qpid-01-500K>
+                        <PQB-Qpid-01-1M>-n PQB-Qpid-01-1M     -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=true  commitBatchSize=1   batchSize=1000   messageSize=1048576 destinationCount=1  rate=0     maxPending=80000000 uniqueDests=true </PQB-Qpid-01-1M>
+
+                        <PQB-Qpid-02-512b>-n PQB-Qpid-02-512b -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=false commitBatchSize=1   batchSize=1000   messageSize=512     destinationCount=1  rate=0     maxPending=80000000 uniqueDests=true </PQB-Qpid-02-512b>
+                        <PQB-Qpid-02-1K>-n PQB-Qpid-02-1K     -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=false commitBatchSize=1   batchSize=1000   messageSize=1024    destinationCount=1  rate=0     maxPending=80000000 uniqueDests=true </PQB-Qpid-02-1K>
+                        <PQB-Qpid-02-5K>-n PQB-Qpid-02-5K     -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=false commitBatchSize=1   batchSize=1000   messageSize=5120    destinationCount=1  rate=0     maxPending=80000000 uniqueDests=true </PQB-Qpid-02-5K>
+                        <PQB-Qpid-02-10K>-n PQB-Qpid-02-10K   -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=false commitBatchSize=1   batchSize=1000   messageSize=10240   destinationCount=1  rate=0     maxPending=80000000 uniqueDests=true </PQB-Qpid-02-10K>
+                        <PQB-Qpid-02-50K>-n PQB-Qpid-02-50K   -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=false commitBatchSize=1   batchSize=1000   messageSize=51200   destinationCount=1  rate=0     maxPending=80000000 uniqueDests=true </PQB-Qpid-02-50K>
+                        <PQB-Qpid-02-100K>-n PQB-Qpid-02-100K -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=false commitBatchSize=1   batchSize=1000   messageSize=102400  destinationCount=1  rate=0     maxPending=80000000 uniqueDests=true </PQB-Qpid-02-100K>
+                        <PQB-Qpid-02-500K>-n PQB-Qpid-02-500K -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=false commitBatchSize=1   batchSize=1000   messageSize=512000  destinationCount=1  rate=0     maxPending=80000000 uniqueDests=true </PQB-Qpid-02-500K>
+                        <PQB-Qpid-02-1M>-n PQB-Qpid-02-1M     -d1M  -s[1000]   -c[1,32],samples=6,exp -o $QPID_WORK/results -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf persistent=true  pubsub=false transacted=false commitBatchSize=1   batchSize=1000   messageSize=1048576 destinationCount=1  rate=0     maxPending=80000000 uniqueDests=true </PQB-Qpid-02-1M>
 
                         <!-- Failover Tests. -->
                         <FT-Qpid-01>-n FT-Qpid-01 -s[2500] -t testAsyncPingOk org.apache.qpid.ping.PingAsyncTestPerf messageSize=256 batchSize=10000 transacted=true broker="tcp://127.0.0.1:5001;tcp://127.0.0.1:5002" failBeforeSend=true -o $QPID_WORK/results</FT-Qpid-01>

Modified: incubator/qpid/branches/M2/java/perftests/src/main/java/org/apache/qpid/ping/PingDurableClient.java
URL: http://svn.apache.org/viewvc/incubator/qpid/branches/M2/java/perftests/src/main/java/org/apache/qpid/ping/PingDurableClient.java?view=diff&rev=567003&r1=567002&r2=567003
==============================================================================
--- incubator/qpid/branches/M2/java/perftests/src/main/java/org/apache/qpid/ping/PingDurableClient.java (original)
+++ incubator/qpid/branches/M2/java/perftests/src/main/java/org/apache/qpid/ping/PingDurableClient.java Fri Aug 17 03:19:54 2007
@@ -28,10 +28,7 @@
 import uk.co.thebadgerset.junit.extensions.util.MathUtils;
 import uk.co.thebadgerset.junit.extensions.util.ParsedProperties;
 
-import javax.jms.Destination;
-import javax.jms.ExceptionListener;
-import javax.jms.JMSException;
-import javax.jms.Message;
+import javax.jms.*;
 
 import java.io.BufferedReader;
 import java.io.IOException;
@@ -220,7 +217,7 @@
 
         // Establish the connection and the message producer.
         establishConnection(true, false);
-        getConnection().start();
+        _connection.start();
 
         Message message = getTestMessage(getReplyDestinations().get(0), _messageSize, _persistent);
 
@@ -330,8 +327,8 @@
         _queueSharedID = new AtomicInteger();
 
         establishConnection(false, true);
-        _consumer.setMessageListener(null);
-        _connection.start();
+        _consumer[0].setMessageListener(null);
+        _consumerConnection[0].start();
 
         // Try to receive all of the pings that were successfully sent.
         int messagesReceived = 0;
@@ -340,7 +337,7 @@
         while (!endCondition)
         {
             // Message received = _consumer.receiveNoWait();
-            Message received = _consumer.receive(TIME_OUT);
+            Message received = _consumer[0].receive(TIME_OUT);
             log.debug("received = " + received);
 
             if (received != null)
@@ -367,7 +364,7 @@
         {
             try
             {
-                _consumerSession.commit();
+                _consumerSession[0].commit();
                 System.out.println("Committed for all messages received.");
             }
             catch (JMSException e)
@@ -376,7 +373,7 @@
                 System.out.println("Error during commit.");
                 try
                 {
-                    _consumerSession.rollback();
+                    _consumerSession[0].rollback();
                     System.out.println("Rolled back on all messages received.");
                 }
                 catch (JMSException e2)

Modified: incubator/qpid/branches/M2/java/perftests/src/main/java/org/apache/qpid/ping/PingTestPerf.java
URL: http://svn.apache.org/viewvc/incubator/qpid/branches/M2/java/perftests/src/main/java/org/apache/qpid/ping/PingTestPerf.java?view=diff&rev=567003&r1=567002&r2=567003
==============================================================================
--- incubator/qpid/branches/M2/java/perftests/src/main/java/org/apache/qpid/ping/PingTestPerf.java (original)
+++ incubator/qpid/branches/M2/java/perftests/src/main/java/org/apache/qpid/ping/PingTestPerf.java Fri Aug 17 03:19:54 2007
@@ -142,7 +142,7 @@
                 perThreadSetup._pingClient.establishConnection(true, true);
             }
             // Start the client connection
-            perThreadSetup._pingClient.getConnection().start();
+            perThreadSetup._pingClient.start();
 
             // Attach the per-thread set to the thread.
             threadSetup.set(perThreadSetup);

Modified: incubator/qpid/branches/M2/java/perftests/src/main/java/org/apache/qpid/requestreply/PingPongProducer.java
URL: http://svn.apache.org/viewvc/incubator/qpid/branches/M2/java/perftests/src/main/java/org/apache/qpid/requestreply/PingPongProducer.java?view=diff&rev=567003&r1=567002&r2=567003
==============================================================================
--- incubator/qpid/branches/M2/java/perftests/src/main/java/org/apache/qpid/requestreply/PingPongTestPerf.java (original)
+++ incubator/qpid/branches/M2/java/perftests/src/main/java/org/apache/qpid/requestreply/PingPongTestPerf.java Fri Aug 17 03:19:54 2007
@@ -20,8 +20,6 @@
  */
 package org.apache.qpid.requestreply;
 
-import javax.jms.*;
-
 import junit.framework.Assert;
 import junit.framework.Test;
 import junit.framework.TestSuite;
@@ -32,6 +30,8 @@
 import uk.co.thebadgerset.junit.extensions.util.ParsedProperties;
 import uk.co.thebadgerset.junit.extensions.util.TestContextProperties;
 
+import javax.jms.*;
+
 /**
  * PingPongTestPerf is a full round trip ping test, that has been written with the intention of being scaled up to run
  * many times simultaneously to simluate many clients/producer/connections. A full round trip ping sends a message from
@@ -196,7 +196,7 @@
                 // Establish a ping-pong client on the ping queue to send the pings and receive replies with.
                 perThreadSetup._testPingProducer = new PingPongProducer(testParameters);
                 perThreadSetup._testPingProducer.establishConnection(true, true);
-                perThreadSetup._testPingProducer.getConnection().start();
+                perThreadSetup._testPingProducer.start();
             }
 
             // Attach the per-thread set to the thread.
--- incubator/qpid/branches/M2/java/perftests/src/main/java/org/apache/qpid/requestreply/PingPongProducer.java (original)
+++ incubator/qpid/branches/M2/java/perftests/src/main/java/org/apache/qpid/requestreply/PingPongProducer.java Fri Aug 17 03:19:54 2007
@@ -84,7 +84,8 @@
  * <tr><td> username         <td> guest    <td> The username to access the broker with.
  * <tr><td> password         <td> guest    <td> The password to access the broker with.
  * <tr><td> selector         <td> null     <td> Not used. Defines a message selector to filter pings with.
- * <tr><td> destinationCount <td> 1        <td> The number of receivers listening to the pings.
+ * <tr><td> destinationCount <td> 1        <td> The number of destinations to send pings to.
+ * <tr><td> numConsumers     <td> 1        <td> The number of consumers on each destination.
  * <tr><td> timeout          <td> 30000    <td> In milliseconds. The timeout to stop waiting for replies.
  * <tr><td> commitBatchSize  <td> 1        <td> The number of messages per transaction in transactional mode.
  * <tr><td> uniqueDests      <td> true     <td> Whether each receivers only listens to one ping destination or all.
@@ -129,7 +130,7 @@
  *       Instead make mina use a bounded blocking buffer, or other form of back pressure, to stop data being written
  *       faster than it can be sent.
  */
-public class PingPongProducer implements Runnable, MessageListener, ExceptionListener
+public class PingPongProducer implements Runnable /*, MessageListener*/, ExceptionListener
 {
     private static final Logger log = Logger.getLogger(PingPongProducer.class);
 
@@ -241,6 +242,12 @@
     /** Defines the default number of destinations to ping. */
     public static final int DESTINATION_COUNT_DEFAULT = 1;
 
+    /** Holds the name of the property to get the number of consumers per destination from. */
+    public static final String NUM_CONSUMERS_PROPNAME = "numConsumers";
+
+    /** Defines the default number consumers per destination. */
+    public static final int NUM_CONSUMERS_DEFAULT = 1;
+
     /** Holds the name of the property to get the waiting timeout for response messages. */
     public static final String TIMEOUT_PROPNAME = "timeout";
 
@@ -309,6 +316,7 @@
         defaults.setPropertyIfNull(FAIL_ONCE_PROPNAME, FAIL_ONCE_DEFAULT);
         defaults.setPropertyIfNull(TX_BATCH_SIZE_PROPNAME, TX_BATCH_SIZE_DEFAULT);
         defaults.setPropertyIfNull(DESTINATION_COUNT_PROPNAME, DESTINATION_COUNT_DEFAULT);
+        defaults.setPropertyIfNull(NUM_CONSUMERS_PROPNAME, NUM_CONSUMERS_DEFAULT);
         defaults.setPropertyIfNull(RATE_PROPNAME, RATE_DEFAULT);
         defaults.setPropertyIfNull(TIMEOUT_PROPNAME, TIMEOUT_DEFAULT);
         defaults.setPropertyIfNull(MAX_PENDING_PROPNAME, MAX_PENDING_DEFAULT);
@@ -361,7 +369,13 @@
     /** Holds the number of sends that should be performed in every transaction when using transactions. */
     protected int _txBatchSize;
 
+    /** Holds the number of destinations to ping. */
     protected int _noOfDestinations;
+
+    /** Holds the number of consumers per destination. */
+    protected int _noOfConsumers;
+
+    /** Holds the maximum send rate in herz. */
     protected int _rate;
 
     /**
@@ -395,8 +409,11 @@
     /** Holds the connection to the broker. */
     protected Connection _connection;
 
+    /** Holds the consumer connections. */
+    protected Connection[] _consumerConnection;
+
     /** Holds the controlSession on which ping replies are received. */
-    protected Session _consumerSession;
+    protected Session[] _consumerSession;
 
     /** Holds the producer controlSession, needed to create ping messages. */
     protected Session _producerSession;
@@ -432,7 +449,7 @@
     protected MessageProducer _producer;
 
     /** Holds the message consumer to receive the ping replies through. */
-    protected MessageConsumer _consumer;
+    protected MessageConsumer[] _consumer;
 
     /**
      * Holds the number of consumers that will be attached to each destination in the test. Each pings will result in
@@ -479,6 +496,7 @@
         _failOnce = properties.getPropertyAsBoolean(FAIL_ONCE_PROPNAME);
         _txBatchSize = properties.getPropertyAsInteger(TX_BATCH_SIZE_PROPNAME);
         _noOfDestinations = properties.getPropertyAsInteger(DESTINATION_COUNT_PROPNAME);
+        _noOfConsumers = properties.getPropertyAsInteger(NUM_CONSUMERS_PROPNAME);
         _rate = properties.getPropertyAsInteger(RATE_PROPNAME);
         _isPubSub = properties.getPropertyAsBoolean(PUBSUB_PROPNAME);
         _isUnique = properties.getPropertyAsBoolean(UNIQUE_DESTS_PROPNAME);
@@ -524,11 +542,17 @@
         createConnection(_clientID);
 
         // Create transactional or non-transactional sessions, based on the command line arguments.
-        _producerSession = (Session) getConnection().createSession(_transacted, _ackMode);
-        _consumerSession = (Session) getConnection().createSession(_transacted, _ackMode);
+        _producerSession = (Session) _connection.createSession(_transacted, _ackMode);
+
+        _consumerSession = new Session[_noOfConsumers];
+
+        for (int i = 0; i < _noOfConsumers; i++)
+        {
+            _consumerSession[i] = (Session) _consumerConnection[i].createSession(_transacted, _ackMode);
+        }
 
         // Create the destinations to send pings to and receive replies from.
-        _replyDestination = _consumerSession.createTemporaryQueue();
+        _replyDestination = _consumerSession[0].createTemporaryQueue();
         createPingDestinations(_noOfDestinations, _selector, _destinationName, _isUnique, _isDurable);
 
         // Create the message producer only if instructed to.
@@ -556,6 +580,13 @@
     protected void createConnection(String clientID) throws AMQException, URLSyntaxException
     {
         _connection = new AMQConnection(_brokerDetails, _username, _password, clientID, _virtualpath);
+
+        _consumerConnection = new Connection[_noOfConsumers];
+
+        for (int i = 0; i < _noOfConsumers; i++)
+        {
+            _consumerConnection[i] = new AMQConnection(_brokerDetails, _username, _password, clientID, _virtualpath);
+        }
     }
 
     /**
@@ -576,13 +607,13 @@
             pingProducer.establishConnection(true, true);
 
             // Start the ping producers dispatch thread running.
-            pingProducer.getConnection().start();
+            pingProducer._connection.start();
 
             // Create a shutdown hook to terminate the ping-pong producer.
             Runtime.getRuntime().addShutdownHook(pingProducer.getShutdownHook());
 
             // Ensure that the ping pong producer is registered to listen for exceptions on the connection too.
-            pingProducer.getConnection().setExceptionListener(pingProducer);
+            pingProducer._connection.setExceptionListener(pingProducer);
 
             // Create the ping loop thread and run it until it is terminated by the shutdown hook or exception.
             Thread pingThread = new Thread(pingProducer);
@@ -743,13 +774,27 @@
 
         for (Destination destination : destinations)
         {
-            // Create a consumer for the destination and set this pinger to listen to its messages.
-            _consumer =
-                _consumerSession.createConsumer(destination, PREFETCH_DEFAULT, NO_LOCAL_DEFAULT, EXCLUSIVE_DEFAULT,
-                    selector);
-            _consumer.setMessageListener(this);
+            _consumer = new MessageConsumer[_noOfConsumers];
+
+            for (int i = 0; i < _noOfConsumers; i++)
+            {
+                // Create a consumer for the destination and set this pinger to listen to its messages.
+                _consumer[i] =
+                    _consumerSession[i].createConsumer(destination, PREFETCH_DEFAULT, NO_LOCAL_DEFAULT, EXCLUSIVE_DEFAULT,
+                        selector);
+
+                final int consumerNo = i;
+
+                _consumer[i].setMessageListener(new MessageListener()
+                    {
+                        public void onMessage(Message message)
+                        {
+                            onMessageWithConsumerNo(message, consumerNo);
+                        }
+                    });
 
-            log.debug("Set this to listen to replies sent to destination: " + destination);
+                log.debug("Set this to listen to replies sent to destination: " + destination);
+            }
         }
     }
 
@@ -760,7 +805,7 @@
      *
      * @param message The received message.
      */
-    public void onMessage(Message message)
+    public void onMessageWithConsumerNo(Message message, int consumerNo)
     {
         // log.debug("public void onMessage(Message message): called");
 
@@ -831,7 +876,7 @@
                     // blocked, even on the last message.
                     if ((remainingCount % _txBatchSize) == 0)
                     {
-                        commitTx(_consumerSession);
+                        commitTx(_consumerSession[consumerNo]);
                     }
 
                     // Forward the message and remaining count to any interested chained message listener.
@@ -956,7 +1001,7 @@
                 log.info("Got all replies on id, " + messageCorrelationId);
             }
 
-            commitTx(_consumerSession);
+            // commitTx(_consumerSession);
 
             log.debug("public int pingAndWaitForReply(Message message, int numPings, long timeout): ending");
 
@@ -1226,6 +1271,16 @@
         _publish = false;
     }
 
+    public void start() throws JMSException
+    {
+        _connection.start();
+
+        for (int i = 0; i < _noOfConsumers; i++)
+        {
+            _consumerConnection[i].start();
+        }
+    }
+
     /** Implements a ping loop that repeatedly pings until the publish flag becomes false. */
     public void run()
     {
@@ -1266,16 +1321,6 @@
     }
 
     /**
-     * Gets the underlying connection that this ping client is running on.
-     *
-     * @return The underlying connection that this ping client is running on.
-     */
-    public Connection getConnection()
-    {
-        return _connection;
-    }
-
-    /**
      * Closes the pingers connection.
      *
      * @throws JMSException All JMSException are allowed to fall through.
@@ -1291,12 +1336,22 @@
                 _connection.close();
                 log.debug("Close connection.");
             }
+
+            for (int i = 0; i < _noOfConsumers; i++)
+            {
+                if (_consumerConnection[i] != null)
+                {
+                    _consumerConnection[i].close();
+                    log.debug("Closed consumer connection.");
+                }
+            }
         }
         finally
         {
             _connection = null;
             _producerSession = null;
             _consumerSession = null;
+            _consumerConnection = null;
             _producer = null;
             _consumer = null;
             _pingDestinations = null;
@@ -1452,7 +1507,7 @@
 
     /**
      * Defines a chained message listener interface that can be attached to this pinger. Whenever this pinger's {@link
      * PingPongProducer#onMessage} method is called, the chained listener set through the {@link
      * PingPongProducer#setChainedMessageListener} method is passed the message, and the remaining expected count of
      * messages with that correlation id.
      *
@@ -1452,7 +1507,7 @@
     /**
      * Defines a chained message listener interface that can be attached to this pinger. Whenever this pinger's {@link
-     * PingPongProducer#onMessage} method is called, the chained listener set through the {@link
+     * PingPongProducer#onMessageWithConsumerNo} method is called, the chained listener set through the {@link
      * PingPongProducer#setChainedMessageListener} method is passed the message, and the remaining expected count of
      * messages with that correlation id.

Modified: incubator/qpid/branches/M2/java/perftests/src/main/java/org/apache/qpid/requestreply/PingPongTestPerf.java
URL: http://svn.apache.org/viewvc/incubator/qpid/branches/M2/java/perftests/src/main/java/org/apache/qpid/requestreply/PingPongTestPerf.java?view=diff&rev=567003&r1=567002&r2=567003
==============================================================================